@@ -11,16 +11,38 @@ is.positive.vector <- function(x) {
 
 
 is.positive_or_NA.finite.vector <- function(x) {
-  if(!is.atomic(x)) {
+  if(!is.atomic(x) || length(x) < 1) {
     return(FALSE)
   }
-  if (!is.positive.finite.vector(x[!is.na(x)])) {
+  if (length(x[!is.na(x)]) > 0 && !is.positive.finite.vector(x[!is.na(x)])) {
     return(FALSE)
   }
   return(TRUE)
 }
 
 
+is.nonnegative_or_NA.finite.vector <- function(x) {
+  if(!is.atomic(x) || length(x) < 1) {
+    return(FALSE)
+  }
+  if (length(x[!is.na(x)]) > 0 && !is.nonnegative.finite.vector(x[!is.na(x)])) {
+    return(FALSE)
+  }
+  return(TRUE)
+}
+
+is.NA.vector <- function(x) {
+  if(!is.atomic(x) || length(x) < 1) {
+    return(FALSE)
+  }
+  if (length(x[!is.na(x)]) > 0) {
+    return(FALSE)
+  }
+  return(TRUE)
+}
+
+
+
 is.nonnegative.vector <- function(x) {
   if(!is.atomic(x) || !is.numeric(x) || length(x) < 1) {
     return(FALSE)
